Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Meta ¶
type Meta struct {
// Pos is the source position.
Pos Position
// LastPos is the last source position.
// Currently it is set when the parsed element type is message, enum, oneof, rpc or service.
LastPos Position
}
Meta represents a meta information about the parsed element.
type Position ¶
type Position struct {
// Filename is a name of file, if any
Filename string
// Offset is a byte offset, starting at 0
Offset int
// Line is a line number, starting at 1
Line int
// Column is a column number, starting at 1 (character count per line)
Column int
}
Position represents a source position.
func NewPosition ¶
NewPosition creates a new Position from scanner.Position.
Click to show internal directories.
Click to hide internal directories.